pub struct FfiExperiment {
pub id: String,
pub traffic_percentage: u8,
pub variants: Variants,
pub context: Condition,
pub status: ExperimentStatusType,
}Fields
id: Stringtraffic_percentage: u8variants: Variantscontext: Conditionstatus: ExperimentStatusTypeTrait Implementations
Sourceimpl Clone for FfiExperiment
impl Clone for FfiExperiment
Sourcefn clone(&self) -> FfiExperiment
fn clone(&self) -> FfiExperiment
Returns a duplicate of the value. Read more
1.0.0 (const: unstable) · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
Performs copy-assignment from
source. Read moreSourceimpl<UT> ConvertError<UT> for FfiExperiment
impl<UT> ConvertError<UT> for FfiExperiment
fn try_convert_unexpected_callback_error( e: UnexpectedUniFFICallbackError, ) -> Result<Self>
Sourceimpl Debug for FfiExperiment
impl Debug for FfiExperiment
Sourceimpl<'de> Deserialize<'de> for FfiExperiment
impl<'de> Deserialize<'de> for FfiExperiment
Sourcefn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
fn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
Deserialize this value from the given Serde deserializer. Read more
Sourceimpl Experimental for FfiExperiment
impl Experimental for FfiExperiment
Sourceimpl ExperimentalVariants for FfiExperiment
impl ExperimentalVariants for FfiExperiment
Sourceimpl<UT> FfiConverter<UT> for FfiExperiment
impl<UT> FfiConverter<UT> for FfiExperiment
Sourceconst TYPE_ID_META: MetadataBuffer
const TYPE_ID_META: MetadataBuffer
Type ID metadata, serialized into a MetadataBuffer.
Sourcetype FfiType = RustBuffer
type FfiType = RustBuffer
The low-level type used for passing values of this type over the FFI. Read more
Sourcefn lower(v: Self) -> RustBuffer
fn lower(v: Self) -> RustBuffer
Lower a rust value of the target type, into an FFI value of type Self::FfiType. Read more
Sourcefn try_lift(buf: RustBuffer) -> Result<Self>
fn try_lift(buf: RustBuffer) -> Result<Self>
Lift a rust value of the target type, from an FFI value of type Self::FfiType. Read more
Sourceimpl From<Experiment> for FfiExperiment
impl From<Experiment> for FfiExperiment
Sourcefn from(experiment: Experiment) -> Self
fn from(experiment: Experiment) -> Self
Converts to this type from the input type.
Sourceimpl<UT> Lift<UT> for FfiExperiment
impl<UT> Lift<UT> for FfiExperiment
Sourceimpl<UT> LiftRef<UT> for FfiExperiment
impl<UT> LiftRef<UT> for FfiExperiment
type LiftType = FfiExperiment
Sourceimpl<UT> LiftReturn<UT> for FfiExperiment
impl<UT> LiftReturn<UT> for FfiExperiment
Sourcetype ReturnType = <FfiExperiment as Lift<UT>>::FfiType
type ReturnType = <FfiExperiment as Lift<UT>>::FfiType
FFI return type for trait interfaces
Sourcefn try_lift_successful_return(v: Self::ReturnType) -> Result<Self>
fn try_lift_successful_return(v: Self::ReturnType) -> Result<Self>
Lift a successfully returned value from a trait interface
Sourcefn lift_foreign_return(
ffi_return: Self::ReturnType,
call_status: RustCallStatus,
) -> Self
fn lift_foreign_return( ffi_return: Self::ReturnType, call_status: RustCallStatus, ) -> Self
Lift a foreign returned value from a trait interface Read more
Sourcefn lift_error(_buf: RustBuffer) -> Self
fn lift_error(_buf: RustBuffer) -> Self
Lift a Rust value for a callback interface method error result Read more
Sourcefn handle_callback_unexpected_error(e: UnexpectedUniFFICallbackError) -> Self
fn handle_callback_unexpected_error(e: UnexpectedUniFFICallbackError) -> Self
Lift a Rust value for an unexpected callback interface error Read more
Sourceimpl<UT> Lower<UT> for FfiExperiment
impl<UT> Lower<UT> for FfiExperiment
type FfiType = <FfiExperiment as FfiConverter<UT>>::FfiType
fn lower(obj: Self) -> Self::FfiType
fn write(obj: Self, buf: &mut Vec<u8>)
Sourcefn lower_into_rust_buffer(obj: Self) -> RustBuffer
fn lower_into_rust_buffer(obj: Self) -> RustBuffer
Convenience method
Sourceimpl<UT> LowerError<UT> for FfiExperiment
impl<UT> LowerError<UT> for FfiExperiment
Sourcefn lower_error(obj: Self) -> RustBuffer
fn lower_error(obj: Self) -> RustBuffer
Lower this value for scaffolding function return Read more
Sourceimpl<UT> LowerReturn<UT> for FfiExperiment
impl<UT> LowerReturn<UT> for FfiExperiment
Sourcetype ReturnType = <FfiExperiment as Lower<UT>>::FfiType
type ReturnType = <FfiExperiment as Lower<UT>>::FfiType
The type that should be returned by scaffolding functions for this type. Read more
Sourcefn lower_return(v: Self) -> Result<Self::ReturnType, RustCallError>
fn lower_return(v: Self) -> Result<Self::ReturnType, RustCallError>
Lower the return value from an scaffolding call Read more
Sourcefn handle_failed_lift(
error: LiftArgsError,
) -> Result<Self::ReturnType, RustCallError>
fn handle_failed_lift( error: LiftArgsError, ) -> Result<Self::ReturnType, RustCallError>
Lower the return value for failed argument lifts Read more
Sourceimpl Serialize for FfiExperiment
impl Serialize for FfiExperiment
Sourceimpl<UT> TypeId<UT> for FfiExperiment
impl<UT> TypeId<UT> for FfiExperiment