Shared JSON schema validation utilities
This module provides validation functions that can be used across the codebase for validating values against JSON schemas.
Enums
- Context
Validation Error - Error type for context and config validation
Functions
- format_
validation_ errors - Format validation errors into a human-readable string
- get_
cohort_ meta_ schema - Get the meta-schema for validating cohort schema definitions
- get_
meta_ schema - Get the meta-schema for validating schema definitions
- try_
into_ jsonschema - Compile a JSON schema for validation
- validate_
against_ schema - Validate a value against a raw JSON schema (compiles and validates)
- validate_
cohort_ dimension_ position - Validate that a cohort dimension’s position is valid relative to its parent dimension
- validate_
cohort_ schema_ structure - Validate the structure of a cohort schema
- validate_
config_ value - Validate a config value against its schema
- validate_
context - Validate a context (condition) against dimension schemas
- validate_
context_ dimension - Validate a context dimension value against its schema
- validate_
overrides - Validate overrides against default config schemas
- validate_
schema - Validate that a JSON schema is well-formed
- validation_
err_ to_ str - Format jsonschema ValidationError instances into human-readable strings